Method: Thor::Command#usage_name

Defined in:
lib/thor/command.rb

#usage_nameString

The command’s name as depicted in it’s #usage message.

We prefer this format when completing commands because it’s how we depict the command to the user.

Returns:

  • (String)

See Also:



210
211
212
# File 'lib/thor/command.rb', line 210

def usage_name
  @usage_name ||= usage.shellsplit[0]
end